==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ko.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "카드에서 사용자 삭제",
    "Hours" : "시간",
    "Minutes" : "분",
    "Deck" : "덱",
    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
    "{user} has shared the board %s with you." : "{user} 님이 %s 게시판을 공유했습니다.",
    "Finished" : "완료됨",
    "To review" : "리뷰할 항목",
    "Action needed" : "동작 필요",
    "Later" : "나중에",
    "Add a new stack" : "새 스택 추가",
    "Submit" : "제출",
    "Show archived cards" : "보관된 카드 보기",
    "Hide archived cards" : "보관된 카드 숨기기",
    "All Boards" : "모든 게시판",
    "Archived boards" : "보관된 게시판",
    "Enter a card title" : "카드 제목 입력",
    "Add card" : "카드 추가",
    "Close" : "닫기",
    "Sharing" : "공유",
    "Tags" : "태그",
    "Select users or groups to share with" : "공유할 사용자나 그룹 선택",
    "No matching user or group found." : "일치하는 사용자나 그룹이 없습니다.",
    "Loading" : "불러오는 중",
    "Edit" : "편집",
    "Share" : "공유",
    "Manage" : "관리",
    "Discard share" : "공유 무시",
    "Create" : "만들기",
    "Create a new tag" : "새 태그 만들기",
    "Status" : "상태",
    "Title" : "제목",
    "Members" : "구성원",
    "More actions" : "더 많은 동작",
    "Edit board" : "게시판 편집",
    "Archive board" : "게시판 보관",
    "Unarchive board" : "게시판 보관 해제",
    "Delete board" : "게시판 삭제",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "게시판 삭제 실행 취소 - 작업을 계속 진행하면 다음 cron 작업 실행 시 게시판을 삭제합니다.",
    "Create new board" : "새 게시판 만들기",
    "New board title" : "새 게시판 제목",
    "by" : "by",
    "Modified:" : "수정한 날짜:",
    "Created:" : "만든 날짜:",
    "Choose a tag" : "태그 선택",
    "Add a tag" : "태그 추가",
    "Select tags" : "태그 선택",
    "Assign users" : "사용자 할당",
    "Choose a user to assign" : "할당할 사용자 선택",
    "Assign this card to a user" : "이 카드를 사용자에게 할당",
    "Due date" : "만료 날짜",
    "Click to set" : "설정하려면 누르기",
    "Remove due date" : "만료 날짜 삭제",
    "Description" : "설명",
    "Saved" : "저장됨",
    "Unsaved changes" : "저장하지 않은 변경 사항",
    "Formatting help" : "서식 도움말",
    "Add a card description…" : "카드 설명 추가…",
    "Shared boards" : "공유된 게시판",
    "Move board to archive" : "게시판을 보관 항목으로 이동",
    "Create a new board" : "새 게시판 만들기"
},
"nplurals=1; plural=0;");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ko.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "카드에서 사용자 삭제",
    "Hours" : "시간",
    "Minutes" : "분",
    "File already exists" : "파일이 이미 존재함",
    "Deck" : "덱",
    "Personal" : "개인",
    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
    "{user} has shared the board %s with you." : "{user} 님이 %s 게시판을 공유했습니다.",
    "Finished" : "완료됨",
    "To review" : "리뷰할 항목",
    "Action needed" : "동작 필요",
    "Later" : "나중에",
    "Done" : "완료",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "Add a new stack" : "새 스택 추가",
    "Submit" : "제출",
    "Show archived cards" : "보관된 카드 보기",
    "Hide archived cards" : "보관된 카드 숨기기",
    "All Boards" : "모든 게시판",
    "Archived boards" : "보관된 게시판",
    "Actions" : "동작",
    "Assign card to me" : "이 카드를 나에게 할당",
    "Unassign card from me" : "이 카드를 나에게 할당 해제",
    "Archive card" : "보관 카드",
    "Delete card" : "카드 삭제",
    "Enter a card title" : "카드 제목 입력",
    "Add card" : "카드 추가",
    "Close" : "닫기",
    "Sharing" : "공유",
    "Tags" : "태그",
    "Select users or groups to share with" : "공유할 사용자나 그룹 선택",
    "Group" : "그룹",
    "Circle" : "서클",
    "No matching user or group found." : "일치하는 사용자나 그룹이 없습니다.",
    "Loading" : "불러오는 중",
    "Edit" : "편집",
    "Share" : "공유",
    "Manage" : "관리",
    "Discard share" : "공유 무시",
    "Create" : "만들기",
    "Create a new tag" : "새 태그 만들기",
    "Status" : "상태",
    "Title" : "제목",
    "Members" : "구성원",
    "More actions" : "더 많은 동작",
    "Edit board" : "게시판 편집",
    "Archive board" : "게시판 보관",
    "Unarchive board" : "게시판 보관 해제",
    "Delete board" : "게시판 삭제",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "게시판 삭제 실행 취소 - 작업을 계속 진행하면 다음 cron 작업 실행 시 게시판을 삭제합니다.",
    "Create new board" : "새 게시판 만들기",
    "New board title" : "새 게시판 제목",
    "Create board" : "새 게시판 만들기",
    "Cancel upload" : "업로드 취소",
    "by" : "by",
    "Modified:" : "수정한 날짜:",
    "Created:" : "만든 날짜:",
    "Choose a tag" : "태그 선택",
    "Add a tag" : "태그 추가",
    "Select tags" : "태그 선택",
    "Assign users" : "사용자 할당",
    "Choose a user to assign" : "할당할 사용자 선택",
    "Assign this card to a user" : "이 카드를 사용자에게 할당",
    "Due date" : "만료 날짜",
    "Click to set" : "설정하려면 누르기",
    "Remove due date" : "만료 날짜 삭제",
    "Description" : "설명",
    "Attachments" : "첨부파일",
    "Saved" : "저장됨",
    "Unsaved changes" : "저장하지 않은 변경 사항",
    "Formatting help" : "서식 도움말",
    "Upload attachment" : "첨부 파일 업로드",
    "Add a card description…" : "카드 설명 추가…",
    "Shared boards" : "공유된 게시판",
    "Move board to archive" : "게시판을 보관 항목으로 이동",
    "Create a new board" : "새 게시판 만들기",
    "Settings" : "설정"
},
"nplurals=1; plural=0;");
